@@ -2,7 +2,6 @@
 # Copyright (c) 2022 Mpltoolbox contributors (https://github.com/mpltoolbox)
 
 from .tool import Tool
-from .utils import make_color
 import numpy as np
 from functools import partial
 from matplotlib.pyplot import Artist, Axes
@@ -21,10 +20,7 @@ class Lines(Tool):
       - Middle-click to delete line
 
     :param ax: The Matplotlib axes to which the Lines tool will be attached.
-    :param n: The number of vertices for each line.
-    :param color: The line colors. Can be a string (all lines will have the same
-        color), a list of strings (one entry per line), or a callable (this will be
-        called every time a new line is created and should return a color).
+    :param n: The number of vertices for each line. Default is 2.
     :param autostart: Automatically activate the tool upon creation if `True`.
     :param on_create: Callback that fires when a line is created.
     :param on_remove: Callback that fires when a line is removed.
@@ -34,17 +30,19 @@ class Lines(Tool):
     :param on_drag_press: Callback that fires when a line is right-clicked.
     :param on_drag_move: Callback that fires when a line is dragged.
     :param on_drag_release: Callback that fires when a line is released.
+    :param kwargs: Matplotlib line parameters used for customization.
+        Each parameter can be a single item (it will apply to all lines),
+        a list of items (one entry per line), or a callable (which will be
+        called every time a new line is created).
     """
 
-    def __init__(self, ax: Axes, n: int, color=None, **kwargs):
+    def __init__(self, ax: Axes, n: int = 2, **kwargs):
         super().__init__(ax, **kwargs)
         self._nmax = n
         self.lines = []
         self._pick_lock = False
         self._moving_vertex_index = None
         self._moving_vertex_artist = None
-        self._color = color
-        self._line_counter = 0
 
     def __del__(self):
         super().shutdown(artists=self.lines)
@@ -54,13 +52,14 @@ class Lines(Tool):
 
     def _make_new_line(self, x: float, y: float):
         xpos, ypos = self._new_line_pos(x, y)
-        line, = self._ax.plot(xpos,
-                              ypos,
-                              '-o',
-                              color=make_color(color=self._color,
-                                               counter=self._line_counter))
+        kwargs = self._parse_kwargs()
+        if set(['ls', 'linestyle']).isdisjoint(set(kwargs.keys())):
+            kwargs['ls'] = 'solid'
+        if 'marker' not in kwargs:
+            kwargs['marker'] = 'o'
+        line, = self._ax.plot(xpos, ypos, **kwargs)
         self.lines.append(line)
-        self._line_counter += 1
+        self._artist_counter += 1
 
     def _on_motion_notify(self, event: Event):
         self._move_vertex(event=event, ind=-1, line=self.lines[-1])
@@ -179,9 +178,3 @@ class Lines(Tool):
 
     def _get_line_length(self, ind: int):
         return len(self.lines[ind].get_xydata())
-
-    def get(self, ind: int) -> np.ndarray:
-        """
-        Get the line data (x, y coordinates) for line identified by its index `ind`.
-        """
-        return self.lines[ind].get_xydata()
