@@ -16,15 +16,16 @@ class Points(Lines):
       - Middle-click to delete point
 
     :param ax: The Matplotlib axes to which the Lines tool will be attached.
-    :param color: The point colors. Can be a string (all lines will have the same
-        color), a list of strings (one entry per point), or a callable (this will be
-        called every time a new point is created and should return a color).
     :param autostart: Automatically activate the tool upon creation if `True`.
     :param on_create: Callback that fires when a point is created.
     :param on_remove: Callback that fires when a point is removed.
     :param on_vertex_press: Callback that fires when a point is left-clicked.
     :param on_vertex_move: Callback that fires when a point is moved.
     :param on_vertex_release: Callback that fires when a point is released.
+    :param kwargs: Matplotlib parameters used for customization.
+        Each parameter can be a single item (it will apply to all points),
+        a list of items (one entry per point), or a callable (which will be
+        called every time a new point is created).
     """
 
     def __init__(self, ax: Axes, **kwargs):
